[gtk/gtk-4-2: 35/91] x11: Be quiet on exit by default




commit 201fc28a67b9c85a4e251ead510d12a42d5fc10e
Author: Matthias Clasen <mclasen redhat com>
Date:   Tue Apr 13 14:52:09 2021 -0400

    x11: Be quiet on exit by default
    
    The condition we check for to catch X servers going away
    may not be accurate anymore, and the warning shows up in
    logs, causing customers to be concerned. So, be quiet by
    default, unless the user explicitly asked for a message.

 gdk/x11/gdkmain-x11.c | 23 ++++++-----------------
 1 file changed, 6 insertions(+), 17 deletions(-)
---
diff --git a/gdk/x11/gdkmain-x11.c b/gdk/x11/gdkmain-x11.c
index 8fc8253295..55afd7f036 100644
--- a/gdk/x11/gdkmain-x11.c
+++ b/gdk/x11/gdkmain-x11.c
@@ -185,24 +185,13 @@ gdk_x_io_error (Display *display)
   /* This is basically modelled after the code in XLib. We need
    * an explicit error handler here, so we can disable our atexit()
    * which would otherwise cause a nice segfault.
    * We fprintf(stderr, instead of g_warning() because g_warning()
    * could possibly be redirected to a dialog
    */
-  if (errno == EPIPE)
-    {
-      g_message ("The application '%s' lost its connection to the display %s;\n"
-                 "most likely the X server was shut down or you killed/destroyed\n"
-                 "the application.\n",
-                 g_get_prgname (),
-                 display ? DisplayString (display) : NULL);
-    }
-  else
-    {
-      g_message ("%s: Fatal IO error %d (%s) on X server %s.\n",
-                 g_get_prgname (),
-                 errno, g_strerror (errno),
-                 display ? DisplayString (display) : NULL);
-    }
+  g_debug ("%s: Fatal IO error %d (%s) on X server %s.\n",
+           g_get_prgname (),
+           errno, g_strerror (errno),
+           display ? DisplayString (display) : "");
 
   _exit (1);
 }
@@ -185,24 +185,13 @@ gdk_x_io_error (Display *display)
    * an explicit error handler here, so we can disable our atexit()
    * which would otherwise cause a nice segfault.
-   * We fprintf(stderr, instead of g_warning() because g_warning()
-   * could possibly be redirected to a dialog
+   * We g_debug() instead of g_warning(), because g_warning()
+   * could possibly be redirected to the log
    */


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]